@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 from abc import ABC
+from collections.abc import Iterable
 from typing import Any, Generic, Literal, TypeVar, cast
 
 import pystac
@@ -142,15 +143,18 @@ class Dimension(ABC):
 
 class SpatialDimension(Dimension):
     @property
-    def extent(self) -> list[float]:
+    def extent(self) -> list[float] | None:
         """Extent (lower and upper bounds) of the dimension as two-dimensional array.
         Open intervals with ``None`` are not allowed."""
-        return get_required(
-            self.properties.get(DIM_EXTENT_PROP), "cube:dimension", DIM_EXTENT_PROP
+        return cast(
+            list[float],
+            get_required(
+                self.properties.get(DIM_EXTENT_PROP), "cube:dimension", DIM_EXTENT_PROP
+            ),
         )
 
     @extent.setter
-    def extent(self, v: list[float]) -> None:
+    def extent(self, v: list[float] | None) -> None:
         self.properties[DIM_EXTENT_PROP] = v
 
     @property
@@ -228,6 +232,19 @@ class VerticalSpatialDimension(SpatialDimension):
     def axis(self, v: VerticalSpatialDimensionAxis) -> None:
         self.properties[DIM_AXIS_PROP] = v
 
+    @property
+    def extent(self) -> list[float] | None:
+        """Extent (lower and upper bounds) of the dimension as two-dimensional array.
+        Open intervals with ``None`` are not allowed."""
+        return self.properties.get(DIM_EXTENT_PROP)
+
+    @extent.setter
+    def extent(self, v: list[float] | None) -> None:
+        if v is None:
+            self.properties.pop(DIM_EXTENT_PROP, None)
+        else:
+            self.properties[DIM_EXTENT_PROP] = v
+
     @property
     def unit(self) -> str | None:
         """The unit of measurement for the data, preferably compliant to `UDUNITS-2
@@ -690,7 +707,7 @@ class AssetDatacubeExtension(DatacubeExtension[pystac.Asset]):
 
     asset_href: str
     properties: dict[str, Any]
-    additional_read_properties: list[dict[str, Any]] | None
+    additional_read_properties: Iterable[dict[str, Any]] | None
 
     def __init__(self, asset: pystac.Asset):
         self.asset_href = asset.href
