@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+from collections.abc import Iterable
 from typing import Any, Generic, Literal, TypeVar
 
 import pystac
@@ -121,7 +122,7 @@ class AssetXarrayAssetsExtension(XarrayAssetsExtension[pystac.Asset]):
 
     asset: pystac.Asset
     properties: dict[str, Any]
-    additional_read_properties: list[dict[str, Any]] | None = None
+    additional_read_properties: Iterable[dict[str, Any]] | None = None
 
     def __init__(self, asset: pystac.Asset):
         self.asset = asset
