@@ -1,13 +1,10 @@
 from __future__ import annotations
 
 import json
-import logging
 import os
 from abc import ABC, abstractmethod
 from collections.abc import Callable
 from typing import TYPE_CHECKING, Any
-from urllib.error import HTTPError
-from urllib.request import Request, urlopen
 
 import pystac
 from pystac.serialization import (
@@ -37,9 +34,6 @@ if TYPE_CHECKING:
     from pystac.stac_object import STACObject
 
 
-logger = logging.getLogger(__name__)
-
-
 class StacIO(ABC):
     _default_io: Callable[[], StacIO] | None = None
 
@@ -95,9 +89,9 @@ class StacIO(ABC):
         """Method used internally by :class:`StacIO` instances to deserialize a
         dictionary from a JSON string.
 
-        This method may be overwritten in :class:`StacIO` sub-classes to provide custom
+        This method may be overwritten in :class:`StacIO` subclasses to provide custom
         deserialization logic. The method accepts arbitrary keyword arguments. These are
-        not used by the default implementation, but may be used by sub-class
+        not used by the default implementation, but may be used by subclass
         implementations.
 
         Args:
@@ -115,9 +109,9 @@ class StacIO(ABC):
         """Method used internally by :class:`StacIO` instances to serialize a dictionary
         to a JSON string.
 
-        This method may be overwritten in :class:`StacIO` sub-classes to provide custom
+        This method may be overwritten in :class:`StacIO` subclasses to provide custom
         serialization logic. The method accepts arbitrary keyword arguments. These are
-        not used by the default implementation, but may be used by sub-class
+        not used by the default implementation, but may be used by subclass
         implementations.
 
         Args:
@@ -138,7 +132,7 @@ class StacIO(ABC):
         root: Catalog | None = None,
         preserve_dict: bool = True,
     ) -> STACObject:
-        """Deserializes a :class:`~pystac.STACObject` sub-class instance from a
+        """Deserializes a :class:`~pystac.STACObject` subclass instance from a
         dictionary.
 
         Args:
@@ -148,8 +142,8 @@ class StacIO(ABC):
             root : Optional root :class:`~pystac.Catalog` to associate with the
                 STAC object.
             preserve_dict: If ``False``, the dict parameter ``d`` may be modified
-                during this method call. Otherwise the dict is not mutated.
-                Defaults to ``True``, which results results in a deepcopy of the
+                during this method call. Otherwise, the dict is not mutated.
+                Defaults to ``True``, which results in a deepcopy of the
                 parameter. Set to ``False`` when possible to avoid the performance
                 hit of a deepcopy.
         """
@@ -286,8 +280,9 @@ class DefaultStacIO(StacIO):
         """Reads file as a UTF-8 string.
 
         If ``href`` has a "scheme" (e.g. if it starts with "https://") then this will
-        use :func:`urllib.request.urlopen` to open the file and read the contents;
-        otherwise, :func:`open` will be used to open a local file.
+        use :func:`urllib.request.urlopen` (or func:`urllib3.PoolManager().request`
+        if available) to open the file and read the contents; otherwise, :func:`open`
+        will be used to open a local file.
 
         Args:
 
@@ -295,11 +290,36 @@ class DefaultStacIO(StacIO):
         """
         href_contents: str
         if _is_url(href):
+            import logging
+            from urllib.error import HTTPError
+            from urllib.request import Request, urlopen
+
+            logger = logging.getLogger(__name__)
             try:
                 logger.debug(f"GET {href} Headers: {self.headers}")
-                req = Request(href, headers=self.headers)
-                with urlopen(req) as f:
-                    href_contents = f.read().decode("utf-8")
+                if HAS_URLLIB3:
+                    http = urllib3.PoolManager()
+                    with http.request(
+                        "GET",
+                        href,
+                        headers={
+                            "User-Agent": f"pystac/{pystac.__version__}",
+                            **self.headers,
+                        },
+                        preload_content=False,  # type: ignore
+                    ) as f:
+                        href_contents = f.read().decode("utf-8")
+                else:
+                    req = Request(
+                        href,
+                        headers={
+                            "User-Agent": f"pystac/{pystac.__version__}",
+                            **self.headers,
+                        },
+                    )
+                    with urlopen(req) as f:
+                        href_contents = f.read().decode("utf-8")
+
             except HTTPError as e:
                 raise Exception(f"Could not read uri {href}") from e
         else:
@@ -430,6 +450,8 @@ if HAS_URLLIB3:
                 href : The URI of the file to open.
             """
             if _is_url(href):
+                from urllib.error import HTTPError
+
                 # TODO provide a pooled StacIO to enable more efficient network
                 # access (probably named `PooledStacIO`).
                 http = PoolManager()
@@ -437,6 +459,10 @@ if HAS_URLLIB3:
                     response = http.request(
                         "GET",
                         href,
+                        headers={
+                            "User-Agent": f"pystac/{pystac.__version__}",
+                            **self.headers,
+                        },
                         retries=self.retry,  # type: ignore
                     )
                     return cast(str, response.data.decode("utf-8"))
