@@ -1,13 +1,12 @@
 from __future__ import annotations
 
+import warnings
 from abc import ABC, abstractmethod
 from collections.abc import Callable, Iterable
-from html import escape
 from typing import TYPE_CHECKING, Any, TypeAlias, TypeVar, cast
 
 import pystac
 from pystac import STACError
-from pystac.html.jinja_env import get_jinja_env
 from pystac.link import Link
 from pystac.utils import (
     HREF,
@@ -266,7 +265,7 @@ class STACObject(ABC):
 
         Raises:
             ValueError: If the self_href is not set, this method will throw
-                a ValueError. Use get_self_href if there may not be an href set.
+                a ValueError. Use get_self_href if there may not be an HREF set.
         """
         result = self.get_self_href()
         if result is None:
@@ -426,12 +425,21 @@ class STACObject(ABC):
         if modify_links:
             links = modify_links(links)
 
+        has_next_link = False
         for i in range(0, len(links)):
             link = links[i]
             if link.rel == rel:
                 link.resolve_stac_object(root=self.get_root())
                 if typ is None or isinstance(link.target, typ):
                     yield cast(STACObject, link.target)
+            if link.rel == "next":
+                has_next_link = True
+        if has_next_link:
+            warnings.warn(
+                "This STAC object has a 'next' link, but pystac does not support "
+                "pagination. If you need to paginate through responses from a STAC "
+                "API, use pystac-client: https://github.com/stac-utils/pystac-client"
+            )
 
     def save_object(
         self,
@@ -584,6 +592,10 @@ class STACObject(ABC):
         raise NotImplementedError
 
     def _repr_html_(self) -> str:
+        from html import escape
+
+        from pystac.html.jinja_env import get_jinja_env
+
         jinja_env = get_jinja_env()
         if jinja_env:
             template = jinja_env.get_template("JSON.jinja2")
@@ -667,8 +679,8 @@ class STACObject(ABC):
                 their latest supported version. Set this to False to disable
                 this behavior.
             preserve_dict: If False, the dict parameter ``d`` may be modified
-                during this method call. Otherwise the dict is not mutated.
-                Defaults to True, which results results in a deepcopy of the
+                during this method call. Otherwise, the dict is not mutated.
+                Defaults to True, which results in a deepcopy of the
                 parameter. Set to False when possible to avoid the performance
                 hit of a deepcopy.
 
@@ -681,7 +693,7 @@ class STACObject(ABC):
     @abstractmethod
     def matches_object_type(cls, d: dict[str, Any]) -> bool:
         """Returns a boolean indicating whether the given dictionary represents a valid
-        instance of this :class:`~pystac.STACObject` sub-class.
+        instance of this :class:`~pystac.STACObject` subclass.
 
         Args:
             d : A dictionary to identify
